==> qt-creator-opensource-src-4.5.0.zip: qt-creator-opensource-src-4.5.0/src/plugins/cpptools/cppeditorwidgetinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "cpptools_global.h"

#include <texteditor/codeassist/assistenums.h>

#include <QString>

namespace TextEditor { class IAssistProvider; }

namespace CppTools {

class CPPTOOLS_EXPORT CppEditorWidgetInterface
{
public:
    void renameUsages(const QString &replacement = QString())
    {
        return renameUsagesInternal(replacement);
    }

    virtual void showPreProcessorWidget() = 0;
    virtual void updateSemanticInfo() = 0;
    virtual void renameUsagesInternal(const QString &replacement) = 0;

    virtual void invokeTextEditorWidgetAssist(TextEditor::AssistKind assistKind,
                                              TextEditor::IAssistProvider *provider) = 0;
};

} // namespace CppTools

==> qt-creator-opensource-src-4.6.0.zip: qt-creator-opensource-src-4.6.0/src/plugins/cpptools/cppeditorwidgetinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "cpptools_global.h"

#include <texteditor/codeassist/assistenums.h>

#include <QString>

namespace TextEditor { class IAssistProvider; }

namespace CppTools {

class SemanticInfo;

class CPPTOOLS_EXPORT CppEditorWidgetInterface
{
public:
    virtual void showPreProcessorWidget() = 0;
    virtual SemanticInfo semanticInfo() const = 0;
    virtual void updateSemanticInfo() = 0;

    virtual void invokeTextEditorWidgetAssist(TextEditor::AssistKind assistKind,
                                              TextEditor::IAssistProvider *provider) = 0;
};

} // namespace CppTools
